@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# SPDX-License-Identifier: LGPL-3.0-only
+
 import json
 import logging
 import requests
@@ -29,38 +31,41 @@ class BaseAPI(object):
     def __init__(self, auth_token, consumer_token):
         self.auth_token = auth_token
         self.consumer_token = consumer_token
-        self.end_point = 'api.packet.net'
+        self.end_point = "api.packet.net"
         self._log = logging.getLogger(__name__)
 
-    def call_api(self, method, type='GET', params=None):  # noqa
+    def call_api(self, method, type="GET", params=None):  # noqa
         if params is None:
             params = {}
 
-        url = 'https://' + self.end_point + '/' + method
+        url = "https://" + self.end_point + "/" + method
 
         headers = {
-            'X-Auth-Token': self.auth_token,
-            'X-Consumer-Token': self.consumer_token,
-            'Content-Type': 'application/json'
+            "X-Auth-Token": self.auth_token,
+            "X-Consumer-Token": self.consumer_token,
+            "Content-Type": "application/json",
         }
 
         # remove token from log
-        headers_str = str(headers).replace(self.auth_token.strip(), 'TOKEN')
-        self._log.debug('%s %s %s %s' % (type, url, params, headers_str))
+        headers_str = str(headers).replace(self.auth_token.strip(), "TOKEN")
+        self._log.debug("%s %s %s %s" % (type, url, params, headers_str))
         try:
-            if type == 'GET':
-                url = url + '%s' % self._parse_params(params)
+            if type == "GET":
+                url = url + "%s" % self._parse_params(params)
                 resp = requests.get(url, headers=headers)
-            elif type == 'POST':
+            elif type == "POST":
                 resp = requests.post(url, headers=headers, data=json.dumps(params))
-            elif type == 'DELETE':
+            elif type == "DELETE":
                 resp = requests.delete(url, headers=headers)
-            elif type == 'PATCH':
+            elif type == "PATCH":
                 resp = requests.patch(url, headers=headers, data=json.dumps(params))
             else:  # pragma: no cover
-                raise Error('method type not recognized as one of GET, POST, DELETE or PATCH: %s' % type)
+                raise Error(
+                    "method type not recognized as one of GET, POST, DELETE or PATCH: %s"
+                    % type
+                )
         except requests.exceptions.RequestException as e:  # pragma: no cover
-            raise Error('Communcations error: %s' % str(e), e)
+            raise Error("Communcations error: %s" % str(e), e)
 
         if not resp.content:
             data = None
@@ -68,7 +73,7 @@ class BaseAPI(object):
             try:
                 data = resp.json()
             except ValueError as e:  # pragma: no cover
-                raise JSONReadError('Read failed: %s' % e.message, e)
+                raise JSONReadError("Read failed: %s" % e.message, e)
         else:
             data = resp.content  # pragma: no cover
 
@@ -76,19 +81,19 @@ class BaseAPI(object):
             msg = data
             if not data:
                 msg = "(empty response)"
-            elif 'errors' in data:
-                msg = ', '.join(data['errors'])
-            raise Error('Error {0}: {1}'.format(resp.status_code, msg))
+            elif "errors" in data:
+                msg = ", ".join(data["errors"])
+            raise Error("Error {0}: {1}".format(resp.status_code, msg))
 
         try:
             resp.raise_for_status()
         except requests.HTTPError as e:  # pragma: no cover
-            raise Error('Error {0}: {1}'.format(resp.status_code, resp.reason), e)
+            raise Error("Error {0}: {1}".format(resp.status_code, resp.reason), e)
 
         self.meta = None
         try:
-            if data and data['meta']:
-                self.meta = data['meta']
+            if data and data["meta"]:
+                self.meta = data["meta"]
         except (KeyError, IndexError):
             pass
 
